*;
*  TO DO: Review the code and the output of the code that
*         creates the data for the three sections of the report.
*;

*  Open the HTML destination to create the procedure output;

ods html path="&PATH" file='ReportData.htm' style=Journal;

*;
*  Create a separate row from specific column values of the 
*  Summary data - Section 1.
*;

data work.report_summary(keep=section rownum indent rowlbl cell avisitn trt01pn idlabel);
set work.summary;
by avisitn trt01pn;

length idlabel $30 rownum indent 8 rowlbl $40 cell $20; 

section = 1;

if (first.trt01pn) then rownum = 0;

*  Column heading;

idlabel = strip(put(trt01pn, colhead.));

* Row Heading;

rownum +1;
indent = 0;
rowlbl = 'Summary Statistics';
cell   = '';
output;

* Row Values;

indent = 1;

rownum +1;
rowlbl = 'n';
cell   = strip(put(n, &STATFMT0D));
output;

rownum +1;
rowlbl = 'Mean';
cell   = strip(put(mean, &STATFMT3D));
output;

rownum +1;
rowlbl = 'SE';
cell   = strip(put(stderr, &STATFMT3D));
output;

rownum +1;
rowlbl = 'Median';
cell   = strip(put(median, &STATFMT3D));
output;

rownum +1;
rowlbl = 'Q1, Q3';
cell   = strip(put(q1, &STATFMT3D)) || ', ' || strip(put(q3, &STATFMT3D));
output;

rownum +1;
rowlbl = 'Min, Max';
cell   = strip(put(min, &STATFMT2D)) || ', ' || strip(put(max, &STATFMT2D));
output;

run;

title 'First 50 Records of the Preliminary Summary Statistics Data';

proc print data=work.report_summary(obs=50);
  var section avisitn trt01pn idlabel rownum rowlbl indent cell;
run; quit;


*;
*  Create a separate row from specific column values of the 
*  LS Means data - Section 2.
*;

proc sort data=work.lsmeans out=work.lsmeans_sorted; by avisitn trt01pn; run; quit;

data work.report_lsmeans(keep=section rownum indent rowlbl cell avisitn trt01pn idlabel);
set work.lsmeans_sorted;
by avisitn trt01pn;

length idlabel $30 rownum indent 8 rowlbl $40 cell $20; 

section = 2;

if (first.trt01pn) then rownum = 0;

*  Column heading;

idlabel = strip(put(trt01pn, colhead.));

* Blank row;

rownum +1;
indent = 0;
rowlbl = '';
cell   = '';
output;

* Row Heading;

indent = 0;
rownum +1;
rowlbl = 'LS Mean';
cell   = '';
output;

* Row Values;

indent = 1;

rownum +1;
rowlbl = 'Estimate (SE)';
cell   = strip(put(estimate, &STATFMT3D)) || ' (' || strip(put(stderr, &STATFMT3D)) || ')';
output;

rownum +1;
rowlbl = '95% CI';
cell   = '(' || strip(put(lower, &STATFMT3D)) || ', ' || strip(put(upper, &STATFMT3D)) || ')';
output;

run;

title 'First 50 Records of the Preliminary LS Means Data';

proc print data=work.report_lsmeans(obs=50);
  var section avisitn trt01pn idlabel rownum rowlbl indent cell;
run; quit;


*;
*  Create a separate row from specific column values of the 
*  differences of LS Means data - Section 3.
*;

proc sort data=work.diffs2 out=work.diffs2_sorted; by avisitn trt01pn; run; quit;

data work.report_diffs(keep=section rownum indent rowlbl cell avisitn trt01pn idlabel);
set work.diffs2_sorted;
by avisitn trt01pn;

length idlabel $30 rownum indent 8 rowlbl $40 cell $20; 

section = 3;

if (first.trt01pn) then rownum = 0;

*  Column heading;

idlabel = strip(put(trt01pn, colhead.));

* Blank row;

rownum +1;
indent = 0;
rowlbl = '';
cell   = '';
output;

* Row Heading;

indent = 0;
rownum +1;
rowlbl = 'Treatment Difference (Active-Placebo)';
cell   = '';
output;

* Row Values;

indent = 1;

rownum +1;
rowlbl = 'Estimate (SE)';
cell   = strip(put(estimate, &STATFMT3D)) || ' (' || strip(put(stderr, &STATFMT3D)) || ')';
output;

rownum +1;
rowlbl = '95% CI';
cell   = '(' || strip(put(lower, &STATFMT3D)) || ', ' || strip(put(upper, &STATFMT3D)) || ')';
output;

rownum +1;
rowlbl = 'Nominal p-value';
cell   = strip(put(probt, pvalue6.4));
output;

run;

title 'First 50 Records of the Preliminary Differences of LS Means Data';

proc print data=work.report_diffs(obs=50);
  var section avisitn trt01pn idlabel rownum rowlbl indent cell;
run; quit;


*  Combine the preliminary data into a single table;

data work.report1;
set work.report_summary
    work.report_lsmeans
    work.report_diffs;
run;

*  Sort in preparation for transposition;

proc sort data=work.report1 out=work.report1_sorted;
  by avisitn section rownum rowlbl indent trt01pn;
run; quit;

*  Transpose the data to get the layout needed for the report;

proc transpose data=work.report1_sorted prefix=trt_ out=work.report_final(drop=_name_);
  by avisitn section rownum rowlbl indent;
  var cell;
  id trt01pn;
  idlabel idlabel;
run; quit;

title 'First 50 Records of the Final Report Data';

proc print data=work.report_final(obs=50);
  var avisitn section rownum indent rowlbl trt_:;
run; quit;

*  Close the HTML destination;

ods html close;

;*';*";*/;quit;run;
* Reference for code above: http://tinyurl.com/mjde9fc ;