*;
*  TO DO: Add the ODS statements to save only the output tables of interest.
*         (Lines 18, 28, and 43)
*         NOTE addition of DATA step code (starting at line 55) and PRINT
*         of preliminary report data (starting at line 75)
*;

*  Turn ODS graphics off;

ods graphics off;

*  Open the HTML destination to create the procedure output;

ods html path="&PATH" file='Statistics.htm' style=Journal;

*  Create data for the column headings of the report;

ods output Summary=work.colhead;

title 'Data Used for the Column Headings of the Report';

proc summary print data=sample.adsl;
  class trt01pn trt01p;
run; quit;

*  Create the statistics for Section 1 of the report;

ods output Summary=work.summary;

title 'Statistics for Section 1 of the Report';

proc summary print data=sample.analysis missing stackods n mean stderr median q1 q3 min max;
  class avisitn trt01pn;
  var chg;
run; quit;

*;
*  Create the statistics for Section 2 and Section 3 of the report.
*  Differences are computed in reference to the placebo 
*  (Active Drug - Placebo).
*;

ods output LSMeans=work.lsmeans SliceDiffs=work.diffs;

title 'Statistics for Sections 2 and 3 of the Report';

proc mixed data=sample.analysis;
  class usubjid avisitn trt01pn;
  model chg = avisitn trt01pn avisitn*trt01pn / ddfm=kenwardroger;
  repeated avisitn / subject=usubjid type=un;
  lsmeans avisitn*trt01pn / cl;
  slice avisitn*trt01pn / cl diff=control('2' '0') sliceby=avisitn;
run; quit;

*;
*  Add a record to the DIFFS table to represent
*  the placebo.  Statistics for these records are missing.
*;

proc sort data=work.diffs out=work.diffs_sorted; by slice; run; quit;

data work.diffs2(drop=stmtno effect slice _trt01pn);
set work.diffs_sorted;
by slice;
length avisitn 8.;
avisitn = input(scan(slice, 2), best.);
output;
if (last.slice) then do;
  trt01pn = _trt01pn;
  call missing(of estimate stderr df tvalue probt alpha lower upper);
  output;
end;
run;

title 'Preliminary Summary Statistics Data Used to Create Column Headings';

proc print data=work.colhead;
  var trt01pn trt01p nobs;
run; quit;

title 'Preliminary Summary Statistics Data of Interest';

proc print data=work.summary;
  var avisitn trt01pn n mean stderr median q1 q3 min max;
run; quit;

title 'Preliminary LS Means Data of Interest';

proc print data=work.lsmeans;
  var avisitn trt01pn estimate stderr lower upper;
run; quit;

title 'Preliminary Differences of LS Means Data of Interest';

proc print data=work.diffs2;
  var avisitn trt01pn estimate stderr lower upper probt;
run; quit;

*  Close the HTML destination;

ods html close;

;*';*";*/;quit;run;
* Reference for code above: http://tinyurl.com/mjde9fc ;